TranslationRepository class abstract
Constructors
- TranslationRepository.create(AiTranslationConfig config, {Client? httpClient})
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void -
getTranslations(
{required Map< String, String> keys, required String sourceLocale, required String targetLocale, required AiTranslationConfig config}) → Future<Map< String, String> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
escapeJsonString(
String value) → String -
getSystemPrompt(
{required String sourceLocale, required String targetLocale, required List< String> ignoreTerms, String? appContextDescription}) → String -
getUserMessage(
{required Map< String, String> keys, required String sourceLocale, required String targetLocale}) → String